@@ -1,6 +1,9 @@
 import fire
 import os
 from pywinschedule.watcher import Watcher
+from pywinschedule.utils.admin import isUserAdmin,runAsAdmin
+if not isUserAdmin():
+    runAsAdmin()
 
 class CLI:
     @classmethod
